bbprep.DitopicFitter
====================

.. currentmodule:: bbprep

.. autoclass:: DitopicFitter
   :members:

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
   
   

   
   
   